pub struct VariationCoords(SmallVec<[(Tag, f32); 2]>);Expand description
List of font variation coordinates by axis tag. If more than one coordinate for a given axis is provided, the last one added is used.
Tuple Fields
0: SmallVec<[(Tag, f32); 2]>Implementations
Sourceimpl VariationCoords
impl VariationCoords
Sourcepub fn new<T: IntoTag>(values: impl IntoIterator<Item = (T, f32)>) -> Self
pub fn new<T: IntoTag>(values: impl IntoIterator<Item = (T, f32)>) -> Self
Create a list of variation coordinates from a sequence of (tag, value) pairs.
Example:
use epaint::text::VariationCoords;
let coords = VariationCoords::new([
(b"wght", 500.0),
(b"wdth", 75.0),
]);pub fn clear(&mut self)